==> zio-aws-dataexchange_2.13-5.17.129.2-sources.jar: zio/aws/dataexchange/model/AssetSourceEntry.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class AssetSourceEntry(bucket: __string, key: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.AssetSourceEntry = {
    import AssetSourceEntry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.AssetSourceEntry
      .builder()
      .bucket(__string.unwrap(bucket): java.lang.String)
      .key(__string.unwrap(key): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.AssetSourceEntry.ReadOnly =
    zio.aws.dataexchange.model.AssetSourceEntry.wrap(buildAwsValue())
}
object AssetSourceEntry {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.AssetSourceEntry
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.AssetSourceEntry =
      zio.aws.dataexchange.model.AssetSourceEntry(bucket, key)
    def bucket: __string
    def key: __string
    def getBucket: ZIO[Any, Nothing, __string] = ZIO.succeed(bucket)
    def getKey: ZIO[Any, Nothing, __string] = ZIO.succeed(key)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.AssetSourceEntry
  ) extends zio.aws.dataexchange.model.AssetSourceEntry.ReadOnly {
    override val bucket: __string =
      zio.aws.dataexchange.model.primitives.__string(impl.bucket())
    override val key: __string =
      zio.aws.dataexchange.model.primitives.__string(impl.key())
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.AssetSourceEntry
  ): zio.aws.dataexchange.model.AssetSourceEntry.ReadOnly = new Wrapper(impl)
}

==> zio-aws-dataexchange_2.13-5.17.152.1-sources.jar: zio/aws/dataexchange/model/AssetSourceEntry.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class AssetSourceEntry(bucket: __string, key: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.AssetSourceEntry = {
    import AssetSourceEntry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.AssetSourceEntry
      .builder()
      .bucket(bucket: java.lang.String)
      .key(key: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.AssetSourceEntry.ReadOnly =
    zio.aws.dataexchange.model.AssetSourceEntry.wrap(buildAwsValue())
}
object AssetSourceEntry {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.AssetSourceEntry
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.AssetSourceEntry =
      zio.aws.dataexchange.model.AssetSourceEntry(bucket, key)
    def bucket: __string
    def key: __string
    def getBucket: ZIO[Any, Nothing, __string] = ZIO.succeed(bucket)
    def getKey: ZIO[Any, Nothing, __string] = ZIO.succeed(key)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.AssetSourceEntry
  ) extends zio.aws.dataexchange.model.AssetSourceEntry.ReadOnly {
    override val bucket: __string = impl.bucket(): __string
    override val key: __string = impl.key(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.AssetSourceEntry
  ): zio.aws.dataexchange.model.AssetSourceEntry.ReadOnly = new Wrapper(impl)
}
